

```python
from pylab import *
x = linspace(0, 2*pi, 1000)
```




```python
x = list(range(20))
print(x)
```

```
[0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19]
```




```
[0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19]
```




```python
print("Hello")
```

```
Hello
```




```python
print("pweave " * 20)
```

```
pweave pweave pweave pweave pweave pweave pweave pweave pweave pweave
pweave pweave pweave pweave pweave pweave pweave pweave pweave pweave
```


Some text in between


```python
print("pweave " * 20)
```

```
pweave pweave pweave pweave pweave pweave pweave pweave pweave pweave pweave pweave pweave pweave pweave pweave pweave pweave pweave pweave
```




```python
print(x)
```




```python
print("**Bold stuff**")
```


**Bold stuff**

